pub struct UnresolvedLink {
pub source: String,
pub target: String,
}Expand description
A wikilink whose target file does not exist among the records the graph was built from.
Fields
source: Stringtarget: StringTrait Implementations
Sourceimpl Clone for UnresolvedLink
impl Clone for UnresolvedLink
Sourcefn clone(&self) -> UnresolvedLink
fn clone(&self) -> UnresolvedLink
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UnresolvedLink
impl Debug for UnresolvedLink
Sourceimpl<'de> Deserialize<'de> for UnresolvedLink
impl<'de> Deserialize<'de> for UnresolvedLink
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for UnresolvedLink
impl PartialEq for UnresolvedLink
Sourcefn eq(&self, other: &UnresolvedLink) -> bool
fn eq(&self, other: &UnresolvedLink) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for UnresolvedLink
impl Serialize for UnresolvedLink
impl Eq for UnresolvedLink
impl StructuralPartialEq for UnresolvedLink