pub fn atomic_write(path: &Path, content: &str) -> Result<()>Expand description
Atomically replace the contents of path with content using the
default WriteOptions (no fsync). See atomic_write_with for the
version that takes options.
pub fn atomic_write(path: &Path, content: &str) -> Result<()>Atomically replace the contents of path with content using the
default WriteOptions (no fsync). See atomic_write_with for the
version that takes options.